---
title: "LGPD"
description: "Terraform compliance scanning for LGPD — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Team" variant="caution" />
<Badge text="Data Protection" variant="tip" />

**Issuing body:** [ANPD](https://www.gov.br/anpd)
**Jurisdiction:** Country — South America
**Countries:** BR


## Assessment

Assess your infrastructure against LGPD for free at any tier:

```bash
complyform assess --frameworks=lgpd
```

## Remediation

Requires Team tier or higher ($1,999/yr) for remediation.

```bash
complyform remediate --frameworks=lgpd
```

## Related Frameworks

No related frameworks in this region.
